### Contributing to the MLCommons

The best way to contribute to the MLCommons is to get involved with one of our many project communities. 
You find more information about getting involved with MLCommons [here](https://mlcommons.org/en/get-involved/#getting-started). 

Generally we encourage people to become a MLCommons member if they wish to contribute to MLCommons projects, 
but outside pull requests are very welcome too.

Regardless of if you are a member, your organization needs to sign the MLCommons CLA. 
Please fill out this [CLA sign up form](https://forms.gle/Ew1KkBVpyeJDuRw67) form to get started.

MLCommons project work is tracked with issue trackers and pull requests. 
Modify the project in your own fork and issue a pull request once you want other developers 
to take a look at what you have done and discuss the proposed changes. 
Ensure that cla-bot and other checks pass for your Pull requests.

Collective Knowledge (CK), Collective Mind (CM) and Common Metadata eXchange (CMX)
were created by [Grigori Fursin](https://arxiv.org/abs/2406.16791),
sponsored by cKnowledge.org and cTuning.org, and donated to MLCommons 
to benefit everyone. Since then, this open-source automation technology
(CM/CMX, CM4MLOps/MLPerf automations, CM4ABTF, CM4Research, etc) is being extended 
as a community effort thanks to all our volunteers, collaborators 
and contributors listed here in alphabetical order:

* @Henryfzh
* @Leonard226
* @Oseltamivir
* @Submandarine
* Resmi Arjun
* Omar Benjelloun (Google)
* Alice Cheng (Nvidia)
* Jiahao Chen (MIT)
* Ramesh N Chukka (Intel)
* Ray DeMoss (One Stop Systems)
* Ryan T DeRue (Purdue University)
* Himanshu Dutta (Indian Institute of Technology)
* Nicolas Essayan
* Justin Faust (One Stop Systems)
* Diane Feddema (Red Hat)
* Leonid Fursin (United Silicon Carbide)
* Anirban Ghosh (Nvidia)
* James Goel (Qualcomm)
* Michael Goin (Neural Magic)
* Jose Armando Hernandez (Paris Saclay University)
* Mehrdad Hessar (OctoML)
* Miro Hodak (AMD)
* Sachin Idgunji (Nvidia)
* Tom Jablin (Google)
* Nino Jacob
* David Kanter (MLCommons)
* Alex Karargyris
* Jason Knight (OctoML)
* Ilya Kozulin (Deelvin)
* @makaveli10 (Collabora)
* Steve Leak(NERSC) 
* Amija Maji (Purdue University)
* Peter Mattson (Google, MLCommons)
* Kasper Mecklenburg (Arm)
* Pablo Gonzalez Mesa
* Thierry Moreau (OctoML)
* Sachin Mudaliyar
* Stanley Mwangi (Microsoft)
* Ashwin Nanjappa (Nvidia)
* Hai Ah Nam (NERSC)
* Nandeeka Nayak (UIUC)
* Datta Nimmaturi (Nutanix)
* Lakshman Patel
* Arun Tejusve Raghunath Rajan (Cruise)
* Vijay Janapa Reddi (Harvard University)
* Andrew Reusch (OctoML)
* Anandhu Sooraj (Kerala Technical University)
* Sergey Serebryakov (HPE)
* Warren Schultz (Principled Technologies)
* Amrutha Sheleenderan (Kerala Technical University)
* Micah J Sheller (Intel)
* Byoungjun Seo (TTA)
* Aditya Kumar Shaw (Indian Institute of Science)
* Ilya Slavutin (Deelvin)
* Jinho Suh (Nvidia)
* Arjun Suresh
* Badhri Narayanan Suresh (Intel)
* David Tafur (MLCommons)
* Chloe Tessier
* Gaurav Verma (Stony Brook University)
* Zixian Wang
* Nathan Wasson
* Scott Wasson (MLCommons)
* Haoyang Zhang  (UIUC)
* Bojian Zheng (University of Toronto)
* Thomas Zhu (Oxford University)
